@@ -7,6 +7,7 @@ var fs = require('fs');
 var path = require('path');
 var crypto = require('crypto');
 var sinon = require('sinon');
+var Buffer = require('safer-buffer').Buffer;
 
 var ED_KEY, ED2_KEY, EC_KEY, EC2_KEY, ECOUT_KEY, DS_KEY, DS2_KEY, DSOUT_KEY;
 var C_KEY, C2_KEY;
@@ -52,8 +53,8 @@ test('derive ed25519 -> curve25519 -> back (negative seed)', function (t) {
 	t.strictEqual(key.size, 256);
 	var key2 = key.derive('ed25519');
 	t.ok(key2.fingerprint().matches(NG_KEY));
-	t.strictEqual(key2.part.r.toString('base64'),
-	    key.part.r.toString('base64'));
+	t.strictEqual(key2.part.k.toString('base64'),
+	    key.part.k.toString('base64'));
 	t.end();
 });
 
@@ -64,8 +65,8 @@ test('derive curve25519 -> ed25519', function (t) {
 	var k2 = k.derive('ed25519');
 	t.strictEqual(k2.type, 'ed25519');
 	t.ok(k2.fingerprint().matches(ED_KEY));
-	t.strictEqual(k2.part.r.toString('base64'),
-	    ED_KEY.part.r.toString('base64'));
+	t.strictEqual(k2.part.k.toString('base64'),
+	    ED_KEY.part.k.toString('base64'));
 	t.end();
 });
 
@@ -108,7 +109,7 @@ test('ecdhe shared secret', function (t) {
 	var dh1 = EC_KEY.createDH();
 	var secret1 = dh1.computeSecret(EC2_KEY.toPublic());
 	t.ok(Buffer.isBuffer(secret1));
-	t.deepEqual(secret1, new Buffer(
+	t.deepEqual(secret1, Buffer.from(
 	    'UoKiio/gnWj4BdV41YvoHu9yhjynGBmphZ1JFbpk30o=', 'base64'));
 
 	var dh2 = EC2_KEY.createDH();
